#ifndef __A16CH_LIB_H_____
#define __A16CH_LIB_H_____

#ifdef __cplusplus
extern "C" {
#endif

#define	BYTE	unsigned char
#define WORD	unsigned short
#define DWORD	unsigned long


// adda errors code

#define		CAP_BASE_ERROR_START	0x0100
#define		CAP_CHAN_ERROR_START	0x0200
#define		CAP_CARD_ERROR_START	0x0300
#define		CAP_LIB_ERROR_START		0x0400

// error code

enum {
	CAP_BASE_DEVICE_OPEN_ERROR	= CAP_BASE_ERROR_START,
	CAP_BASE_NO_HANDLE,

	CAP_CARD_CHANNEL_OVERFLOW = CAP_CARD_ERROR_START

};


// 
// eeprom virtual status report code
enum {
	EEP_ERASE_ALL_START = 0,
	EEP_ERASE_ALL_ENDED,
	EEP_PROG_START,
	EEP_PROG_SECTOR,
	EEP_PROG_ENDED,
	EEP_VERIFY_START,
	EEP_VERIFY_ENDED,
	EEP_PROG_FILE_OPEN_ERROR,
	EEP_LOAD_FILE
};

virtual class eepReport  
{
public:
	eepReport() {}
	virtual ~eepReport() {};
	virtual void Status(int msg,int par) {};
};



extern BOOL _stdcall _export ADDA_Init();
extern BOOL _stdcall _export ADDA_End();
extern int _stdcall _export ADDA_GetMaxCards();
extern int _stdcall _export ADDA_GetMaxChannels(int card_num);
extern int _stdcall _export ADDA_GetID(int card_num);
extern int _stdcall _export ADDA_WriteReg(int card_num,DWORD offset,DWORD data);
extern int _stdcall _export ADDA_ReadReg(int card_num,DWORD offset,DWORD *data);
extern int _stdcall _export ADDA_InIrqSet(int card_num,DWORD ipen, DWORD inen);
extern int _stdcall _export ADDA_InRead(int card_num,DWORD *data);
extern int _stdcall _export ADDA_InReadOvl(int card_num,DWORD *data,DWORD *status);
extern int _stdcall _export ADDA_CancelReadOvl(int card_num);
extern int _stdcall _export ADDA_OutWrite(int card_num,DWORD data);

// DAC 16 channel, ADC 16 channel parameter meaning
extern int _stdcall _export ADDA_GetDacBuf(int card_num,int channel,BYTE **Buf);
extern int _stdcall _export ADDA_DmaDacStart(int card_num,int channel,DWORD length,int sample_rate);
extern int _stdcall _export ADDA_DmaDacStop(int card_num,int channel);
extern int _stdcall _export ADDA_GetDmaDacPosOvl(int card_num,int channel,DWORD *pos);
extern int _stdcall _export ADDA_CancelGetDmaDacPos(int card_num,int channel);
extern int _stdcall _export ADDA_SetDacSigned(int card_num,DWORD flags);	// bit 0 to 15 defines each DAC channel's data signed or unsigned

// ADC 16 channel
extern int _stdcall _export ADDA_GetAdcBuf(int card_num,int channel,BYTE **Buf);
extern int _stdcall _export ADDA_DmaAdcStart(int card_num,int channel,DWORD length,int sample_rate);	// length is DMA block length
extern int _stdcall _export ADDA_DmaAdcStop(int card_num,int channel);
extern int _stdcall _export ADDA_GetDmaAdcPosOvl(int card_num,int channel,DWORD *pos);
extern int _stdcall _export ADDA_CancelGetDmaAdcPos(int card_num,int channel);
extern int _stdcall _export ADDA_SetAdcSigned(int card_num,DWORD flags);	// bit 0 to 15 defines each ADC channel's data is signed or unsigned
extern int _stdcall _export ADDA_SetAdcSampleTickToCounter0Trg(int card_num,DWORD flags);	// bit 0 to 15 defines each ADC channel's sample tick to counter 0 trg output or not
extern int _stdcall _export ADDA_PutDac(int card_num,int channel,WORD data);
extern int _stdcall _export ADDA_GetAdc(int card_num,int channel,WORD *data);		// read Adc then request new adc
extern int _stdcall _export ADDA_ReqReadAdc(int card_num,int channel,WORD *data);	// request ADC then read the result
extern int _stdcall _export ADDA_ReqAdc(int card_num,int chan_bits);				// channel bit flag
extern int _stdcall _export ADDA_IsAdcEnded(int card_num,int channel);			// return 1 if ok
extern int _stdcall _export ADDA_ReadAdc(int card_num,int channel,WORD *data);
extern int _stdcall _export ADDA_SetAdcSingleMode(int card_num,DWORD flags);	// bit 0 to 15 defines each ADC channel's single input mode or not

// eeprom program 
extern void _stdcall _export ADDA_SetRpt(int card_num,eepReport *report);
extern int _stdcall _export ADDA_Prog(int card_num,char *filename);

// ADC trigger control functions
extern void _stdcall _export ADDA_SetTrgSrc(int card_num,int channel,DWORD src);

// position controller 
extern void _stdcall _export ADDA_SetPosIrqEnable(int card_num,DWORD data);	// bit flags for each channel
extern int _stdcall _export ADDA_GetPosition(int card_num,int channel,DWORD *pos);
extern DWORD _stdcall _export ADDA_GetPosStatus(int card_num);
extern void _stdcall _export ADDA_ClrPosStatus(int card_num,DWORD data);

// analog trigger event generator
extern void _stdcall _export ADDA_SetAnalogPara(int card_num,int channel,int mode,int ref_value);
extern DWORD _stdcall _export ADDA_GetAnalogTrgStatus(int card_num);
extern void _stdcall _export ADDA_ClrAnalogTrg(int card_num,DWORD data);

// digital trigger event generator
extern void _stdcall _export ADDA_SetDigitalPara(int card_num,DWORD pen,DWORD nen);
extern DWORD _stdcall _export ADDA_GetDigitalTrgStatus(int card_num);
extern void _stdcall _export ADDA_ClrDigitalTrg(int card_num,DWORD data);


// counter & timer 
extern void _stdcall _export ADDA_SetCounterPara(int card_num,int encoder_mode,int src,DWORD reload_value);
extern void _stdcall _export ADDA_SetCounterIrqMode(int card_num,int ien);
extern DWORD _stdcall _export ADDA_GetCounterStatus(int card_num);
extern void _stdcall _export ADDA_AckCounterStatus(int card_num,DWORD data);
extern DWORD _stdcall _export ADDA_GetEncoderValue(int card_num);


// trigger overlapped event control functions
extern int _stdcall _export ADDA_GetPositionOvl(int card_num,int channel, DWORD *pos);
extern int _stdcall _export ADDA_CancelGetPositionOvl(int card_num,int channel);
extern int _stdcall _export ADDA_WaitCountOvl(int card_num);
extern int _stdcall _export ADDA_CancelWaitCountOvl(int card_num);

extern BYTE* _stdcall _export ADDA_GetIoStart(int card_num);

#ifdef __cplusplus
}
#endif

#endif
